@@ -19,25 +19,31 @@ _DROP_FUNCTIONS = {
 # Ignore SIGPIPE
 signal.signal(signal.SIGPIPE, signal.SIG_DFL)
 
-now = int( time.time() )
+now = int(time.time())
 yesterday = now - (60 * 60 * 24)
 
 option_parser = optparse.OptionParser(usage='''%prog [options] path''')
-option_parser.add_option('--from', default=yesterday, type='int', dest='_from',
+option_parser.add_option(
+  '--from', default=yesterday, type='int', dest='_from',
   help=("Unix epoch time of the beginning of "
         "your requested interval (default: 24 hours ago)"))
-option_parser.add_option('--until', default=now, type='int',
+option_parser.add_option(
+  '--until', default=now, type='int',
   help="Unix epoch time of the end of your requested interval (default: now)")
-option_parser.add_option('--json', default=False, action='store_true',
+option_parser.add_option(
+  '--json', default=False, action='store_true',
   help="Output results in JSON form")
-option_parser.add_option('--pretty', default=False, action='store_true',
+option_parser.add_option(
+  '--pretty', default=False, action='store_true',
   help="Show human-readable timestamps instead of unix times")
-option_parser.add_option('--drop',
-                         choices=list(_DROP_FUNCTIONS.keys()),
-                         action='store',
-                         help="Specify 'nulls' to drop all null values. \
-Specify 'zeroes' to drop all zero values. \
-Specify 'empty' to drop both null and zero values")
+option_parser.add_option(
+  '-t', '--time-format', action='store', type='string', dest='time_format',
+  help='Time format to use with --pretty; see time.strftime()')
+option_parser.add_option(
+  '--drop', choices=list(_DROP_FUNCTIONS.keys()), action='store',
+  help="Specify 'nulls' to drop all null values. "
+       "Specify 'zeroes' to drop all zero values. "
+       "Specify 'empty' to drop both null and zero values")
 
 (options, args) = option_parser.parse_args()
 
@@ -47,8 +53,8 @@ if len(args) != 1:
 
 path = args[0]
 
-from_time = int( options._from )
-until_time = int( options.until )
+from_time = int(options._from)
+until_time = int(options.until)
 
 try:
   data = whisper.fetch(path, from_time, until_time)
@@ -60,29 +66,32 @@ except (whisper.WhisperException, IOError) as exc:
 
 if options.drop:
   fcn = _DROP_FUNCTIONS.get(options.drop)
-  values = [ x for x in values if fcn(x) ]
+  values = [x for x in values if fcn(x)]
 
-(start,end,step) = timeInfo
+(start, end, step) = timeInfo
 
 if options.json:
-  values_json = str(values).replace('None','null')
+  values_json = str(values).replace('None', 'null')
   print('''{
     "start" : %d,
     "end" : %d,
     "step" : %d,
     "values" : %s
-  }''' % (start,end,step,values_json))
+  }''' % (start, end, step, values_json))
   sys.exit(0)
 
 t = start
 for value in values:
   if options.pretty:
-    timestr = time.ctime(t)
+    if options.time_format:
+      timestr = time.strftime(options.time_format, time.localtime(t))
+    else:
+      timestr = time.ctime(t)
   else:
     timestr = str(t)
   if value is None:
     valuestr = "None"
   else:
     valuestr = "%f" % value
-  print("%s\t%s" % (timestr,valuestr))
+  print("%s\t%s" % (timestr, valuestr))
   t += step
