@@ -21,8 +21,6 @@ try:
 except ImportError:
     from os import listdir as scandir
 
-RESIZE_BIN = "/opt/graphite/bin/whisper-resize.py"
-INFO_BIN = "/opt/graphite/bin/whisper-info.py"
 LOG = logging.getLogger()
 LOG.setLevel(logging.INFO)
 SCHEMA_LIST = {}
@@ -31,7 +29,6 @@ DEFAULT_SCHEMA = {'match': re.compile('.*'),
                   'retentions': '1m:7d'}
 DEBUG = False
 DRY_RUN = False
-BASE_COMMAND = [RESIZE_BIN]
 ROOT_PATH = ""
 
 
@@ -92,7 +89,7 @@ def fix_metric(metric):
     command_string = list(BASE_COMMAND) + [metric]
 
     retention = DEFAULT_SCHEMA['retentions']
-    matching = metric[len(ROOT_PATH):]
+    matching = metric[len(ROOT_PATH):].replace('/', '.')
     for schema, info in SCHEMA_LIST.iteritems():
         if info['match'].search(matching):
             retention = info['retentions']
@@ -109,14 +106,19 @@ def fix_metric(metric):
         res = 0
     else:
         LOG.debug('Retention will be %s' % retention)
+        # record file owner/group and perms to set properly after whisper-resize.py is complete
+        st = os.stat(metric)
         if DEBUG:
             res = subprocess.check_call(command_string)
         else:
             res = subprocess.check_call(command_string,
                                         stdout=devnull)
+        os.chmod(metric, st.st_mode)
+        os.chown(metric, st.st_uid, st.st_gid)
+
     devnull.close()
     # wait for a second, so we don't kill I/O on the host
-    time.sleep(0.3)
+    time.sleep(SLEEP)
     """
     We have manual commands for every failed file from these
     errors, so we can just go through each of these errors
@@ -170,6 +172,12 @@ def cli_opts():
     parser.add_argument('--aggregate', action='store_true', dest='aggregate',
                         help="Passed through to whisper-resize.py, roll up values",
                         default=False)
+    parser.add_argument('--bindir', action='store', dest='bindir',
+                        help="The root path to whisper-resize.py and whisper-info.py",
+                        default='/opt/graphite/bin')
+    parser.add_argument('--sleep', action='store', type=float, dest='sleep',
+                        help="Sleep this amount of time in seconds between metric comparisons",
+                        default=0.3)
     return parser.parse_args()
 
 
@@ -187,6 +195,12 @@ if __name__ == '__main__':
     ROOT_PATH = i_args.path
     DEBUG = i_args.debug
     DRY_RUN = i_args.dry_run
+    BINDIR = i_args.bindir
+    SLEEP = i_args.sleep
+    RESIZE_BIN = BINDIR + "/whisper-resize.py"
+    INFO_BIN = BINDIR + "/whisper-info.py"
+    BASE_COMMAND = [RESIZE_BIN]
+
     if i_args.nobackup:
         BASE_COMMAND.append('--nobackup')
     if i_args.aggregate:
